/*$$$ 
<filter id="charcoalShader" label="Graphic Pen" category="effects" vartype="custom"
	source1="charcoalMap">
	<var varname="color1" label="Color 1" type="coloralpha" default="ff000000" />
	<var varname="color2" label="Color 2" type="coloralpha" default="ffffffff" />
	<var varname="lightLevel" label="Chalk Amount" numFactor="100" type="number" min="0" max="1" default="0.9" />
	<var varname="darkLevel" label="Charcoal Amount" numFactor="100" type="number" min="0" max="1" default="0.9" />
</filter>
$$$*/

precision highp float;

uniform sampler2D tt_uniform_maintexture;
uniform sampler2D tt_uniform_texture1;

uniform int tt_uniform_imagewidth;
uniform int tt_uniform_imageheight;
uniform int tt_uniform_surfacewidth;
uniform int tt_uniform_surfaceheight;
uniform float tt_uniform_pixelwidth;
uniform float tt_uniform_pixelheight;

uniform vec4 color1;
uniform vec4 color2;
uniform float lightLevel;
uniform float darkLevel;

varying vec2 mainTexCoord;

void main()
{
	int imgWidth = tt_uniform_imagewidth;
	int imgHeight = tt_uniform_imageheight;
	int surfWidth = tt_uniform_surfacewidth;
	int surfHeight = tt_uniform_surfaceheight;
	float pixWidth = tt_uniform_pixelwidth;
	float pixHeight = tt_uniform_pixelheight;

        vec4 colWhite = color2;
        vec4 colDark = color1;
        float whiteFactor;
        float darkFactor;
        float greyFactor;
        
        float whiteLum;
        float darkLum;
        
        vec4 outCol;
        
		vec2 coord = mainTexCoord;
        vec4 col = texture2D( tt_uniform_maintexture, coord );

        float lum = (0.299*col.r + 0.587*col.g + 0.114*col.b);
        
        lum = smoothstep(0.0,1.0,lum);
        
  		whiteLum = 0.5 + (1.0-lightLevel)*0.5;
 		darkLum = 0.5 + (1.0-darkLevel)*0.5;
 		
        whiteFactor = smoothstep(whiteLum - 0.05,whiteLum,lum);
        darkFactor = smoothstep(darkLum - 0.05,darkLum,1.0-lum);

      	whiteLum = 1.0 - max(lum - whiteLum,0.0)/(1.0-whiteLum);
        darkLum = 1.0 - max((1.0-lum) - darkLum,0.0)/(1.0-darkLum);        
       
 		coord.x *= float(surfWidth);
		coord.y *= float(surfHeight);

		vec2 curCoord = 2.0*coord;
		
		curCoord.x -= floor(curCoord.x/512.0) * 512.0;
		curCoord.y -= floor(curCoord.y/512.0) * 512.0;
		
		curCoord.x /= 512.0;
		curCoord.y /= 512.0;
        
        vec4 col2 = texture2D( tt_uniform_texture1, curCoord );
        
  
        outCol = mix(color1,color2,0.5);
        
       whiteFactor *= smoothstep(-0.3+whiteLum,0.3+whiteLum,col2.r);
        // whiteFactor += smoothstep(0.0+whiteLum,0.6+whiteLum,col2.r) * (1.0 - whiteFactor);
        
        darkFactor *= smoothstep(-0.3+darkLum,0.3+darkLum,col2.g);
      // darkFactor += smoothstep(0.0+darkLum,0.6+darkLum,col2.g) * (1.0 - darkFactor);
        
        greyFactor = 1.0 - (whiteFactor + darkFactor);
        
        outCol = outCol*greyFactor + colDark*darkFactor + colWhite*whiteFactor;
		
		SHIFTCOMPS(outCol)
	
		gl_FragColor = outCol;
	
}
