/*$$$ 
<filter id="directionalBlurShader" label="Directional Blur" category="effects" samplingMode="linear" vartype="custom"
	source1="noise" noiseWidth="256" noiseHeight="256" noiseBaseX="4.0" noiseBaseY="4.0" noiseOctaves="1">
	<var varname="angle" label="Angle" type="angle" min="0" max="360" default="0" />
	<var varname="blurSize" label="Size" type="number" min="0" max="100" default="0" />
</filter>
$$$*/

precision highp float;

uniform sampler2D tt_uniform_maintexture;
uniform sampler2D tt_uniform_texture1;

uniform int tt_uniform_imagewidth;
uniform int tt_uniform_imageheight;
uniform int tt_uniform_surfacewidth;
uniform int tt_uniform_surfaceheight;
uniform float tt_uniform_pixelwidth;
uniform float tt_uniform_pixelheight;

uniform float angle;
uniform float blurSize;

varying vec2 mainTexCoord;

void main()
{
	const float PI = 3.14159265358979323846264338327950288;

	int imgWidth = tt_uniform_imagewidth;
	int imgHeight = tt_uniform_imageheight;
	int surfWidth = tt_uniform_surfacewidth;
	int surfHeight = tt_uniform_surfaceheight;
	float pixWidth = tt_uniform_pixelwidth;
	float pixHeight = tt_uniform_pixelheight;

	float rAngle = PI * -angle / 180.0;
	
	vec2 coord = mainTexCoord;
	vec2 curCoord;
	vec4 outCol;
	vec4 noiseCol;
	vec2 rotCoord = coord;
	vec2 jitterCoord;
	
	float jitterSize;
	
	curCoord.x = coord.x * float(surfWidth);
	curCoord.y = coord.y * float(surfHeight);
	
	curCoord.x -= floor(curCoord.x/256.0) * 256.0;
	curCoord.y -= floor(curCoord.y/256.0) * 256.0;
	
	curCoord.x /= 256.0;
	curCoord.y /= 256.0;
	
	noiseCol = texture2D( tt_uniform_texture1, curCoord );
	
	jitterSize = (noiseCol.r - 0.5);
	
	rotCoord.x = pixWidth*(blurSize * cos(rAngle))/5.0;
	rotCoord.y = pixHeight*(blurSize * -sin(rAngle))/5.0;
	
	jitterCoord.x = rotCoord.x*jitterSize;
	jitterCoord.y = rotCoord.y*jitterSize;
	
	curCoord.x = coord.x;
	curCoord.y = coord.y;
	
	outCol = texture2D( tt_uniform_maintexture, curCoord );
	
	curCoord.x = coord.x - rotCoord.x + jitterCoord.x;
	curCoord.y = coord.y - rotCoord.y + jitterCoord.y;
	
	outCol += texture2D( tt_uniform_maintexture, curCoord );
	
	curCoord.x = coord.x + rotCoord.x + jitterCoord.x;
	curCoord.y = coord.y + rotCoord.y + jitterCoord.y;
	
	outCol += texture2D( tt_uniform_maintexture, curCoord );
	
	curCoord.x = coord.x - 2.0*rotCoord.x + jitterCoord.x;
	curCoord.y = coord.y - 2.0*rotCoord.y + jitterCoord.y;
	
	outCol += texture2D( tt_uniform_maintexture, curCoord );
	
	curCoord.x = coord.x + 2.0*rotCoord.x + jitterCoord.x;
	curCoord.y = coord.y + 2.0*rotCoord.y + jitterCoord.y;
	
	outCol += texture2D( tt_uniform_maintexture, curCoord );
	
	curCoord.x = coord.x - 3.0*rotCoord.x + jitterCoord.x;
	curCoord.y = coord.y - 3.0*rotCoord.y + jitterCoord.y;
	
	outCol += texture2D( tt_uniform_maintexture, curCoord );
	
	curCoord.x = coord.x + 3.0*rotCoord.x + jitterCoord.x;
	curCoord.y = coord.y + 3.0*rotCoord.y + jitterCoord.y;
	
	outCol += texture2D( tt_uniform_maintexture, curCoord );
	
	curCoord.x = coord.x - 4.0*rotCoord.x + jitterCoord.x;
	curCoord.y = coord.y - 4.0*rotCoord.y + jitterCoord.y;
	
	outCol += texture2D( tt_uniform_maintexture, curCoord );
	
	curCoord.x = coord.x + 4.0*rotCoord.x + jitterCoord.x;
	curCoord.y = coord.y + 4.0*rotCoord.y + jitterCoord.y;
	
	outCol += texture2D( tt_uniform_maintexture, curCoord );
	
	curCoord.x = coord.x - 5.0*rotCoord.x + jitterCoord.x;
	curCoord.y = coord.y - 5.0*rotCoord.y + jitterCoord.y;
	
	outCol += texture2D( tt_uniform_maintexture, curCoord );
	
	curCoord.x = coord.x + 5.0*rotCoord.x + jitterCoord.x;
	curCoord.y = coord.y + 5.0*rotCoord.y + jitterCoord.y;
	
	outCol += texture2D( tt_uniform_maintexture, curCoord );
	
	gl_FragColor = outCol / 11.0;
	
}
