/*$$$ 
<filter id="graphicPenShader" label="Graphic Pen" category="effects" vartype="custom"
	source1="noise" noiseWidth="256" noiseHeight="256" noiseBaseX="2.0" noiseBaseY="2.0" noiseOctaves="1">
	<var varname="color1" label="Color 1" type="coloralpha" default="ff000000" />
	<var varname="color2" label="Color 2" type="coloralpha" default="ffffffff" />
	<var varname="direction" label="Angle" type="angle" min="0" max="360" default="45" />
	<var varname="scale" label="Size" type="number" min="1" max="20" default="15" />
</filter>
$$$*/

precision highp float;

uniform sampler2D tt_uniform_maintexture;
uniform sampler2D tt_uniform_texture1;

uniform int tt_uniform_imagewidth;
uniform int tt_uniform_imageheight;
uniform int tt_uniform_surfacewidth;
uniform int tt_uniform_surfaceheight;
uniform float tt_uniform_pixelwidth;
uniform float tt_uniform_pixelheight;

uniform vec4 color1;
uniform vec4 color2;
uniform float direction;
uniform float scale;

varying vec2 mainTexCoord;

void main()
{
	const float PI = 3.14159265358979323846264338327950288;

	int imgWidth = tt_uniform_imagewidth;
	int imgHeight = tt_uniform_imageheight;
	int surfWidth = tt_uniform_surfacewidth;
	int surfHeight = tt_uniform_surfaceheight;
	float pixWidth = tt_uniform_pixelwidth;
	float pixHeight = tt_uniform_pixelheight;

	
	vec2 coord = mainTexCoord;
	vec2 curCoord;
	lowp vec4 outCol;
	lowp vec4 noiseCol;
    float lum;
    float factor;

    float angle = -direction*PI/180.0;
    float a = sin(angle);
    float b = cos(angle);
	
	coord.x *= float(surfWidth);
	coord.y *= float(surfHeight);
	
    curCoord.y = 1.5*(coord.x*a + coord.y*b);
    curCoord.x = curCoord.y/2.0 + 1.5*(coord.x*b - coord.y*a)/scale;

	curCoord.x -= floor(curCoord.x/256.0) * 256.0;
	curCoord.y -= floor(curCoord.y/256.0) * 256.0;
	
	curCoord.x /= 256.0;
	curCoord.y /= 256.0;
	
	noiseCol = texture2D( tt_uniform_texture1, curCoord );
	
	outCol = texture2D( tt_uniform_maintexture, mainTexCoord );
	
    lum = (outCol.r + outCol.g + outCol.b)/3.0;
    factor = 1.0 - 2.0*abs(lum-0.5);
 	
    lum = floor(0.5 + (lum + 2.0*factor*(noiseCol.r-0.5)));
	
	outCol = mix(color1,color2,lum);
	
	SHIFTCOMPS(outCol)
	
	gl_FragColor = outCol;
	
}
