/*$$$ 
<filter id="halftoneShader" label="Halftone Pattern" category="effects" vartype="custom"
	source1="noise" noiseWidth="256" noiseHeight="256" noiseBaseX="2.0" noiseBaseY="2.0" noiseOctaves="1">
	<var varname="color1" label="Color 1" type="coloralpha" default="ff000000" />
	<var varname="color2" label="Color 2" type="coloralpha" default="ffffffff" />
	<var varname="scale" label="Scale" type="number" min="5" max="50" default="15" />
	<var varname="direction" label="Direction" type="angle" min="0" max="360" default="20" />
</filter>
$$$*/

precision highp float;

uniform sampler2D tt_uniform_maintexture;
uniform sampler2D tt_uniform_texture1;

uniform int tt_uniform_imagewidth;
uniform int tt_uniform_imageheight;
uniform int tt_uniform_surfacewidth;
uniform int tt_uniform_surfaceheight;
uniform float tt_uniform_pixelwidth;
uniform float tt_uniform_pixelheight;

uniform vec4 color1;
uniform vec4 color2;

uniform float direction;
uniform float scale;

varying vec2 mainTexCoord;

void main()
{
	const float PI = 3.14159265358979323846264338327950288;

	int imgWidth = tt_uniform_imagewidth;
	int imgHeight = tt_uniform_imageheight;
	int surfWidth = tt_uniform_surfacewidth;
	int surfHeight = tt_uniform_surfaceheight;
	float pixWidth = tt_uniform_pixelwidth;
	float pixHeight = tt_uniform_pixelheight;
	
	float angle = PI*direction/180.0;
	float offset = scale;
	vec4 dst;
	
	vec2 coord = mainTexCoord;
	
    vec2 rot;
    vec2 center;
    float pLen = offset/1.414213562373095;
    
    coord.x *= float(tt_uniform_surfacewidth);
    coord.y *= float(tt_uniform_surfaceheight);
    
    rot.x = coord.x * cos(angle) + coord.y * sin(angle);
    rot.y = coord.x * -sin(angle) + coord.y * cos(angle);
    
    center = floor(0.5 + rot/offset) * offset;
    
    rot.x = center.x * cos(-angle) + center.y * sin(-angle);
    rot.y = center.x * -sin(-angle) + center.y * cos(-angle);
   
    dst = texture2D( tt_uniform_maintexture, mainTexCoord );
    center = coord - rot;
    
    float light = 1.0 - (dst.r + dst.g + dst.b)/3.0;
	light = smoothstep(-0.5+light,0.5+light,length(center)/pLen);
	
	dst = mix(color1,color2,light);
	
	SHIFTCOMPS(dst)
	
	gl_FragColor = dst;
	
}
