/*$$$ 
<filter id="monitorShader" label="Monitor" category="effects" samplingMode="linear" vartype="intensity" source1="blur" blurAmount="15.0" >
	<var varname="intensity" label="Intensity" type="number" numFactor="100" min="0" max="1" default="0.7" />
</filter>
$$$*/

precision highp float;

uniform sampler2D tt_uniform_maintexture;
uniform sampler2D tt_uniform_texture1;

uniform int tt_uniform_imagewidth;
uniform int tt_uniform_imageheight;
uniform int tt_uniform_surfacewidth;
uniform int tt_uniform_surfaceheight;
uniform float tt_uniform_pixelwidth;
uniform float tt_uniform_pixelheight;

uniform float intensity;

varying vec2 mainTexCoord;

void main()
{
	int imgWidth = tt_uniform_imagewidth;
	int imgHeight = tt_uniform_imageheight;
	int surfWidth = tt_uniform_surfacewidth;
	int surfHeight = tt_uniform_surfaceheight;
	float pixWidth = tt_uniform_pixelwidth;
	float pixHeight = tt_uniform_pixelheight;

    vec4 dst;
    vec4 blurCol;
	
	const float PI2 = 2.0*3.14159265358979323846264338327950288;
	
	vec3 maskR = vec3(1.0,0.0,1.0);
	vec3 maskG = vec3(1.0,0.0,1.0);
	vec3 maskB = vec3(1.0,0.0,1.0);
	
	vec2 vecR = vec2(-6.0*pixWidth,-4.0*pixHeight);
	vec2 vecG = vec2(6.0*pixWidth,8.0*pixHeight);
	vec2 vecB = vec2(8.0*pixWidth,-4.0*pixHeight);
	
	
	vec2 coord = mainTexCoord;
	
	float offset = coord.y*float(surfHeight);
	float offsetX = coord.x*float(surfWidth);
	
    float yMod = mod(offset,2.0);
    maskR.x = mix(1.0,0.75 + float(mod(offsetX+yMod,3.0) == 0.0)*0.25,intensity);
    maskG.x = mix(1.0,0.75 + float(mod(offsetX+yMod+1.0,3.0) == 0.0)*0.25,intensity);
    maskB.x = mix(1.0,0.75 + float(mod(offsetX+yMod+2.0,3.0) == 0.0)*0.25,intensity);

	float factor = mix(1.0,(0.5 + (1.0+sin(mod(offset*1.3,PI2)))/4.0),intensity);
	vec2 center;
	
	center.x = 0.5*float(imgWidth)/float(surfWidth);
	center.y = 0.5*float(imgHeight)/float(surfHeight);
	
	float weight = length(coord-center);
	weight = intensity*smoothstep(0.0,1.0,weight);
	
	blurCol = texture2D( tt_uniform_texture1, mainTexCoord );

	vec4 colR = texture2D( tt_uniform_maintexture, coord+vecR*weight) * maskR.xyyz;
	vec4 colG = texture2D( tt_uniform_maintexture, coord+vecG*weight) * maskG.yxyz;
	vec4 colB = texture2D( tt_uniform_maintexture, coord+vecB*weight) * maskB.yyxz;
	
	dst = (colR + colG + colB);
	dst.rgb *= factor;

	blurCol.rgb = smoothstep(0.33,1.0,blurCol.rgb)*intensity;
	
 	dst.rgb +=  blurCol.rgb * (1.0 - (dst.rgb * 0.5));

	gl_FragColor = dst;
}
