/*$$$ 
<filter id="multiGradientMapShader" label="Gradient Map" category="generic" vartype="custom">
	<var varname="color1" label="Color 1" type="coloralpha" default="ff000000" />
	<var varname="color2" label="Color 2" type="coloralpha" default="ff001966" />
	<var varname="color3" label="Color 3" type="coloralpha" default="ff0099e5" />
	<var varname="color4" label="Color 4" type="coloralpha" default="ffffffff" />
	<var varname="gamma" label="Gamma" type="number" numFactor="100" min="-1" max="1" default="0" />
</filter>
$$$*/

precision highp float;

uniform sampler2D tt_uniform_maintexture;

uniform int tt_uniform_imagewidth;
uniform int tt_uniform_imageheight;
uniform float tt_uniform_pixelwidth;
uniform float tt_uniform_pixelheight;

uniform vec4 color1;
uniform vec4 color2;
uniform vec4 color3;
uniform vec4 color4;
uniform float gamma;

varying vec2 mainTexCoord;

void main()
{
    vec4 dst;

	vec4 col = texture2D(tt_uniform_maintexture, mainTexCoord.xy);
	
	
    vec4 startColor = color1;
    vec4 endColor = color2;
    
    SHIFTCOMPS(col)
    
    float lum = 0.299*col.r + 0.587*col.g + 0.114*col.b;

    //float alpha = col.a;
    
    if(gamma > 0.0)
        lum = pow(lum,1.0/(1.0 + gamma));
    else
        lum = pow(lum,1.0 - gamma);
    
    lum = lum*3.0;
    
    if(lum  >2.0)
    {
        startColor = color3;
        endColor = color4;
        lum -= 2.0;
    }
    else
    {
        if(lum  > 1.0)
        {
            startColor = color2;
            endColor = color3;
            lum -= 1.0;
        }
    }
    
    lum = smoothstep(0.0,1.0,lum); 

    dst = col;
    
    //startColor.rgb *= startColor.a;
    //endColor.rgb *= endColor.a;
    
    dst = mix(startColor, endColor,lum);
    //dst.a *= alpha;

	SHIFTCOMPS(dst)
	
	gl_FragColor = dst;
}
