/*$$$ 
<filter id="oldPhotoCopyShader" label="Graphic Pen" category="effects" vartype="custom" source1="scratchesMap">
	<var varname="color1" label="Color 1" type="coloralpha" default="ff000000" />
	<var varname="color2" label="Color 2" type="coloralpha" default="ffffffff" />
	<var varname="threshold" label="Threshold" numFactor="100" type="number" min="0" max="1" default="0.5" />
</filter>
$$$*/

precision highp float;

uniform sampler2D tt_uniform_maintexture;
uniform sampler2D tt_uniform_texture1;

uniform int tt_uniform_imagewidth;
uniform int tt_uniform_imageheight;
uniform int tt_uniform_surfacewidth;
uniform int tt_uniform_surfaceheight;
uniform float tt_uniform_pixelwidth;
uniform float tt_uniform_pixelheight;

uniform vec4 color1;
uniform vec4 color2;
uniform float threshold;

varying vec2 mainTexCoord;

void main()
{
	const float PI = 3.14159265358979323846264338327950288;

	int imgWidth = tt_uniform_imagewidth;
	int imgHeight = tt_uniform_imageheight;
	int surfWidth = tt_uniform_surfacewidth;
	int surfHeight = tt_uniform_surfaceheight;
	float pixWidth = tt_uniform_pixelwidth;
	float pixHeight = tt_uniform_pixelheight;
	
	
	vec2 coord = mainTexCoord;
	lowp vec4 outCol;
	lowp vec4 noiseCol;
    float lum;
    float factor = threshold*0.5;

	coord.x *= float(surfWidth);
	coord.y *= float(surfHeight);
	
	coord.x -= floor(coord.x/512.0) * 512.0;
	coord.y -= floor(coord.y/512.0) * 512.0;
	
	coord.x /= 512.0;
	coord.y /= 512.0;
	
	noiseCol = texture2D( tt_uniform_texture1, coord );
	
	outCol = texture2D( tt_uniform_maintexture, mainTexCoord );
	
    lum = (outCol.r + outCol.g + outCol.b)/3.0;
    
    lum = max(lum,factor);
    lum = min(lum,0.2 + factor);
 	
    lum = smoothstep(factor,0.2 + factor,lum);
	lum += noiseCol.b*noiseCol.b*(1.0 - lum);
	
	outCol = mix(color1,color2,lum);
	
	SHIFTCOMPS(outCol)
	
	gl_FragColor = outCol;
	
}
