/*$$$ 
<filter id="replaceColorShader" label="Replace Color" category="generic" vartype="custom">
	<var varname="sampleColor" label="Sample Color" type="color" default="00ccff" />
	<var varname="minLum" label="Sample Color" type="coloralpha" default="ff00ff" />
	<var varname="threshold" label="Threshold" type="number" min="0" max="1" default="0.25" />
	<var varname="intensity" label="Amount" type="number" min="0" max="1" default="1.0" />
</filter>
$$$*/

precision highp float;

uniform sampler2D tt_uniform_maintexture;

uniform int tt_uniform_imagewidth;
uniform int tt_uniform_imageheight;
uniform float tt_uniform_pixelwidth;
uniform float tt_uniform_pixelheight;

uniform vec3 sampleColor;
uniform vec4 replaceColor;
uniform float threshold;
uniform float intensity;

varying vec2 mainTexCoord;

void main()
{
     // temporary variables to hold the colors.
    vec4 dst;

	vec4 curColor;
	vec3 cmpIQ;
	vec3 iQ;
	vec3 replaceIQ;

	float replaceY;
	float diffY;
	float dist;
	float tres;
	float factor;
	vec3 dotVector = vec3(0.299,0.587,0.114);

  	mat3 YIQMatrix = mat3(
        0.596, -0.275, -0.321,
        0.207, -0.497, 0.290,
        0.1495, 0.2935, 0.057
     );

 	mat3 RGBMatrix = mat3(
	0.9489, 0.6561, 1.0,
	-0.702213117546848, -0.684742589437819, 1.0,
	-1.127, 1.805, 1.0
	);

	curColor = texture2D(tt_uniform_maintexture, mainTexCoord.xy);
	
	SHIFTCOMPS(curColor)

	cmpIQ = sampleColor.rgb * YIQMatrix;
	iQ = curColor.rgb * YIQMatrix;
	
	factor = intensity;
	
	tres = threshold*threshold;

	dst = curColor;
	
	dist = distance(cmpIQ,iQ);
	
	if(dist < tres)
	{
		if(dist > (tres*0.75))
		{
			factor *= 1.0 - (dist-(tres*0.75))/(tres-(tres*0.75));
		}
		
		diffY = dot(dotVector,replaceColor.rgb);
		diffY -= dot(dotVector,sampleColor.rgb);
		replaceY = dot(dotVector,curColor.rgb) + diffY;
		
		replaceY = max(replaceY,0.0);
		replaceY = min(replaceY,1.0);
		
		replaceIQ = replaceColor.rgb * YIQMatrix;
		replaceIQ.z = replaceY;
		
		curColor.a = replaceColor.a;
		curColor.rgb = replaceIQ * RGBMatrix;
		curColor.rgb = min(curColor.rgb,vec3(curColor.a,curColor.a,curColor.a));
		
		dst = mix(dst,curColor,factor);
	}
	
	SHIFTCOMPS(dst)
	
	gl_FragColor.rgb = min(dst.rgb,dst.a);
	gl_FragColor.a = dst.a;
}
