/*$$$ 
<filter id="saturationShader" label="Saturation" category="adjustment" vartype="intensity">
	<var varname="intensity" label="Intensity" type="number" min="-1" max="1" default="0" />
</filter>
$$$*/

precision highp float;

uniform sampler2D tt_uniform_maintexture;

uniform int tt_uniform_imagewidth;
uniform int tt_uniform_imageheight;
uniform float tt_uniform_pixelwidth;
uniform float tt_uniform_pixelheight;

uniform float intensity;

varying vec2 mainTexCoord;

void main()
{
	int imgWidth = tt_uniform_imagewidth;
	int imgHeight = tt_uniform_imageheight;
	float pixWidth = tt_uniform_pixelwidth;
	float pixHeight = tt_uniform_pixelheight;

    vec4 dst;

	vec4 curCol;
	vec4 srcCol;
	
    float lum;
    float skinFactor;
    float curVal;
    float factor = 1.0;
	
	srcCol = texture2D(tt_uniform_maintexture, mainTexCoord.xy);
	
	SHIFTCOMPS(srcCol)
	
	curCol = srcCol;
	
	lum = 0.299*curCol.r + 0.587*curCol.g + 0.114*curCol.b;
	
     if(intensity < 0.0)
     {
         factor = -intensity;
         curCol.r = lum;
         curCol.g = lum;
         curCol.b = lum;
     }
     else
     {
         skinFactor = 1.0 - max(curCol.r - (curCol.g+curCol.b)/2.0,0.0);
         skinFactor *= skinFactor;
         curVal = 1.0;
         
         if(curCol.r != lum)
         {
              if(curCol.r<lum)
                 curVal = lum/(lum-curCol.r);
             else
                 curVal = (1.0-lum)/(curCol.r-lum);
         }
         if(curVal < factor || factor == 1.0)
             factor = curVal;
         
          if(curCol.g != lum)
         {
              if(curCol.g<lum)
                 curVal = lum/(lum-curCol.g);
             else
                 curVal = (1.0-lum)/(curCol.g-lum);
         }
         if(curVal < factor || factor == 1.0)
             factor = curVal;

       if(curCol.b != lum)
         {
              if(curCol.b<lum)
                 curVal = lum/(lum-curCol.b);
             else
                 curVal = (1.0-lum)/(curCol.b-lum);
         }
         
         if(curVal < factor || factor == 1.0)
             factor = curVal;
         if(factor > 2.0)
             factor = 2.0;
             
         curCol.r = (curCol.r - lum)*factor + lum;
         curCol.g = (curCol.g - lum)*factor + lum;
         curCol.b = (curCol.b - lum)*factor + lum;
         
         factor = intensity*skinFactor;
     }
     
     dst.xyz = mix(srcCol.xyz,curCol.xyz,factor);
     dst.xyz = min(dst.xyz,srcCol.w);
	 dst.w = srcCol.w;
	
	SHIFTCOMPS(dst)
	
	gl_FragColor = dst;
}
