/*$$$ 
<filter id="sleepyHollowShader" label="Old Sepia" category="effects" vartype="intensity" source1="blur" blurAmount="10.0">
	<var varname="intensity" label="Intensity" type="number" numFactor="100" min="0" max="1" default="1" />
</filter>
$$$*/

precision highp float;

uniform sampler2D tt_uniform_maintexture;
uniform sampler2D tt_uniform_texture1;

uniform int tt_uniform_imagewidth;
uniform int tt_uniform_imageheight;
uniform int tt_uniform_surfacewidth;
uniform int tt_uniform_surfaceheight;
uniform float tt_uniform_pixelwidth;
uniform float tt_uniform_pixelheight;

uniform float intensity;

varying vec2 mainTexCoord;

void main()
{
	int imgWidth = tt_uniform_imagewidth;
	int imgHeight = tt_uniform_imageheight;
	int surfWidth = tt_uniform_surfacewidth;
	int surfHeight = tt_uniform_surfaceheight;
	float pixWidth = tt_uniform_pixelwidth;
	float pixHeight = tt_uniform_pixelheight;

    vec4 dst;
    vec4 rgbaColor;
    vec4 yiqaColor;
    vec4 blurCol;
   	vec2 curCoord;
   	 
    vec2 vignetteVec;
    float darkFactor;
    float blurFactor;
    
    const mat4 YIQMatrix = mat4(
        0.299,  0.596,  0.212, 0.000,
        0.587, -0.275, -0.523, 0.000,
        0.114, -0.321,  0.311, 0.000,
        0.000,  0.000,  0.000, 1.000
    );

    const mat4 inverseYIQ = mat4(
        1.0,    1.0,    1.0,    0.0,
        0.956, -0.272, -1.10,  0.0,
        0.621, -0.647,  1.70,   0.0,
        0.0,    0.0,    0.0,    1.0
    );
	

	curCoord.x = mainTexCoord.x * float(surfWidth);
	curCoord.y = mainTexCoord.y * float(surfHeight);
	
	vignetteVec.x = curCoord.x/float(imgWidth) - 0.5;
	vignetteVec.y = curCoord.y/float(imgHeight) - 0.5;

	blurCol = texture2D( tt_uniform_texture1, mainTexCoord );
	
	blurFactor = (blurCol.r + blurCol.g + blurCol.b)/3.0;
	blurFactor = 1.0 - blurFactor;
	blurFactor *= blurFactor;
	blurFactor = 1.0 - blurFactor;
	
	darkFactor = length(vignetteVec);
	
	darkFactor = 1.0 - smoothstep(0.3,1.0,darkFactor);
	darkFactor *= blurFactor;

    rgbaColor = texture2D(tt_uniform_maintexture, mainTexCoord.xy);
	SHIFTCOMPS(rgbaColor)

	dst = rgbaColor;

	yiqaColor = YIQMatrix * rgbaColor;
   
    yiqaColor.x = smoothstep(0.0,1.0,yiqaColor.x) * darkFactor;
	yiqaColor.y *= 0.5;
	rgbaColor = inverseYIQ * yiqaColor;
	
    dst.rgb = mix(dst.rgb,rgbaColor.rgb,intensity);
	dst.a = rgbaColor.a;
	
	SHIFTCOMPS(dst)
	
	gl_FragColor.rgb = min(dst.rgb,dst.a);
	gl_FragColor.a = dst.a;
}
